embassy-usb-host

Crates

git

Versions

default

Flavors

EndpointDescriptor

Struct EndpointDescriptor 

pub struct EndpointDescriptor {
    pub endpoint_address: u8,
    pub attributes: u8,
    pub max_packet_size: u16,
    pub interval: u8,
}
Standard USB Endpoint Descriptor.

Contains information to determine the bandwidth requirements. (USB 2.0 9.6.6)

Fields

endpoint_address: u8

Endpoint address.

Contains the endpoint number and direction.

attributes: u8

Endpoint attribute bitmap.

max_packet_size: u16

Maximum packet size (11 bits).

For high-speed isochronous and interrupt endpoints, it also specifies aditional transaction opportunities.

interval: u8

Polling interval.

The meaning of this value depends on the transfer type and speed.

Implementations

Source

impl EndpointDescriptor

pub fn ep_dir(&self) -> Direction

Returns the endpoint direction.

pub fn ep_type(&self) -> EndpointType

Returns the endpoint transfer type.

pub fn ep_number(&self) -> u8

Endpoint number (0-15).

pub fn is_in(&self) -> bool

True if this is an IN endpoint.

pub fn transfer_type(&self) -> u8

Transfer type (0=Control, 1=Isochronous, 2=Bulk, 3=Interrupt).