embassy-usb-host

Crates

git

Versions

default

Flavors

ConfigurationDescriptor

Struct ConfigurationDescriptor 

pub struct ConfigurationDescriptor {
    pub total_len: u16,
    pub num_interfaces: u8,
    pub configuration_value: u8,
    pub configuration_name: StringIndex,
    pub attributes: u8,
    pub max_power: u8,
}
Standard USB Configuration Descriptor.

When a configuration descriptor is requested, all related descriptors are returned. (USB 2.0 9.6.3)

Fields

total_len: u16

Total length of data returned for this configuration.

The data includes this descriptor, interface descriptors, endpoint descriptors, and possibly other descriptors.

num_interfaces: u8

Number of interface descriptors.

configuration_value: u8

Configuration ID.

configuration_name: StringIndex

Configuration string.

attributes: u8

Configuration attribute bitmap.

max_power: u8

Maximum bus power that will be consumed in 2mA units.