embassy-usb-host

Crates

git

Versions

default

Flavors

ConfigurationDescriptor

Struct ConfigurationDescriptor 

pub struct ConfigurationDescriptor<'a> {
    pub len: u8,
    pub descriptor_type: u8,
    pub total_len: u16,
    pub num_interfaces: u8,
    pub configuration_value: u8,
    pub configuration_name: StringIndex,
    pub attributes: u8,
    pub max_power: u8,
    pub buffer: &'a [u8],
}
USB Configuration Descriptor header with a reference to the sub-descriptor buffer.

Fields

len: u8descriptor_type: u8total_len: u16num_interfaces: u8configuration_value: u8configuration_name: StringIndexattributes: u8max_power: u8buffer: &'a [u8]

The raw bytes following the 9-byte header (interface + endpoint descriptors).

Implementations

Source

impl<'a> ConfigurationDescriptor<'a>

pub fn try_from_slice(buf: &'a [u8]) -> Result<Self, HostError>

Parse a full Configuration Descriptor blob, giving access to sub-descriptors via iterators.

pub fn iter_descriptors(&self) -> RawDescriptorIterator<'_>

Iterate over all raw descriptors in this Configuration.

pub fn iter_interface(&self) -> InterfaceIterator<'_>

Iterate over all interface descriptors of this Configuration.