pub type InterfaceDescriptorChain<'a> = DescriptorChain<'a, InterfaceDescriptor>;Expand description
The chain of descriptors of a InterfaceDescriptor.
A ConfigurationDescriptorChain provides one or more interface descriptors (USB 2.0 9.6.5). Each interface chain includes endpoint descriptors, and possibly other descriptors.
The buffer goes up to the next interface descriptor.
Aliased Type
pub struct InterfaceDescriptorChain<'a> {
pub descriptor: InterfaceDescriptor,
pub buffer: &'a [u8],
}Fields
descriptor: InterfaceDescriptorThe current descriptor.
buffer: &'a [u8]The raw bytes following the descriptor.
Implementations
Sourceimpl<'a> InterfaceDescriptorChain<'a>
impl<'a> InterfaceDescriptorChain<'a>
Sourcepub fn iter_descriptors(&self) -> RawDescriptorIterator<'_> ⓘ
pub fn iter_descriptors(&self) -> RawDescriptorIterator<'_> ⓘ
Iterate over raw descriptors inside this interface.
Sourcepub fn iter_endpoints(&'a self) -> EndpointIterator<'a> ⓘ
pub fn iter_endpoints(&'a self) -> EndpointIterator<'a> ⓘ
Iterate over endpoint descriptors inside this interface.